<?php
/**
 * @copyright	Copyright (C) 2005 - 2012 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die;

/**
 * @since		1.5
 */
class modMenuWithItemSelectionHelper
{
	/**
	 * Get a list of the menu items.
	 *
	 * @param	JRegistry	$params	The module options.
	 *
	 * @return	array
	 * @since	1.5
	 */
	static function getList(&$params)
	{
		$app = JFactory::getApplication();
		$menu = $app->getMenu();

		// If no active menu, use default
		$active = ($menu->getActive()) ? $menu->getActive() : $menu->getDefault();

		$user = JFactory::getUser();
		$levels = $user->getAuthorisedViewLevels();
		asort($levels);
		$key = 'menu_items'.$params.implode(',', $levels).'.'.$active->id;
		$cache = JFactory::getCache('mod_menuwithitemselection', '');
		if (!($items = $cache->get($key)))
		{
			// Initialise variables.
			$list		= array();
			$db			= JFactory::getDbo();

			$ignoreBasicOptions = $params->get('ignoreBasicOptions');
			$itemsToShow = $params->get('itemsToShow', array());

			$path		= $active->tree;
			$start		= $ignoreBasicOptions ? 1 : (int) $params->get('startLevel');
			$end		= (int) $params->get('endLevel');
			$showAll	= $params->get('showAllChildren');
			$items 		= $ignoreBasicOptions ? self::getAllItemsOrderedByMenuType() : $menu->getItems('menutype',$params->get('menutype'));

			$lastitem	= 0;

			if ($items) {
				foreach($items as $i => $item)
				{
					if (($ignoreBasicOptions && array_search($item->id, $itemsToShow) === false) || (
					    !$ignoreBasicOptions && (
						($start && $start > $item->level)
						|| ($end && $item->level > $end)
						|| (!$showAll && $item->level > 1 && !in_array($item->parent_id, $path))
						|| ($start > 1 && !in_array($item->tree[$start-2], $path))))
					) {
						unset($items[$i]);
						continue;
					}

					$item->deeper = false;
					$item->shallower = false;
					$item->level_diff_to_shallower = 0;
					$item->level_diff_from_shallower = 0;

					if (isset($items[$lastitem])) {
						$items[$lastitem]->deeper		= ($item->level > $items[$lastitem]->level);
						$items[$lastitem]->shallower	= ($item->level < $items[$lastitem]->level);
						if ($items[$lastitem]->shallower) {
							$items[$lastitem]->level_diff_to_shallower = ($items[$lastitem]->level - $item->level);
						} else if ($items[$lastitem]->deeper) {
							$item->level_diff_from_shallower = ($item->level - $items[$lastitem]->level);
						}
					}

					$item->parent = (boolean) $menu->getItems('parent_id', (int) $item->id, true);

					$lastitem			= $i;
					$item->active		= false;
					$item->flink = $item->link;
					
					// Set $secure to the $items param
					$secure = $item->params->get('secure');

					switch ($item->type)
					{
						case 'separator':
							// No further action needed.
							continue;

						case 'url':
							if ((strpos($item->link, 'index.php?') === 0) && (strpos($item->link, 'Itemid=') === false)) {
								// If this is an internal Joomla link, ensure the Itemid is set.
								$item->flink = $item->link.'&Itemid='.$item->id;
							}
							break;

						case 'alias':
							// If this is an alias use the item id stored in the parameters to get the aliased item.
							$alias = $menu->getItem($item->params->get('aliasoptions'));
							// Change $secure value to match aliased menu item
							$secure = $alias->params->get('secure');
							// Use the alias item id to make the link
							$item->flink = 'index.php?Itemid='.$alias->id;
							break;

						default:
							$router = JSite::getRouter();
							if ($router->getMode() == JROUTER_MODE_SEF) {
								$item->flink = 'index.php?Itemid='.$item->id;
							}
							else {
								$item->flink .= '&Itemid='.$item->id;
							}
							break;
					}

					if (strcasecmp(substr($item->flink, 0, 4), 'http') && (strpos($item->flink, 'index.php?') !== false)) {
						$item->flink = JRoute::_($item->flink, true, $secure);
					}
					else {
						$item->flink = JRoute::_($item->flink);
					}

					$item->title = htmlspecialchars($item->title);
					$item->anchor_css = htmlspecialchars($item->params->get('menu-anchor_css', ''));
					$item->anchor_title = htmlspecialchars($item->params->get('menu-anchor_title', ''));
					$item->menu_image = $item->params->get('menu_image', '') ? htmlspecialchars($item->params->get('menu_image', '')) : '';
				}

				$firstItem = reset($items);
				if ($firstItem) {
					//The first item is a special case. As it has no previous
					//item, the level difference must be calculated against the
					//base of the list (which is 1 level below the start level).
					$firstItem->level_diff_from_shallower = $firstItem->level - (($start?$start:1) - 1);
				}

				if (isset($items[$lastitem])) {
					$items[$lastitem]->deeper		= (($start?$start:1) > $items[$lastitem]->level);
					$items[$lastitem]->shallower	= (($start?$start:1) < $items[$lastitem]->level);
					$items[$lastitem]->level_diff_to_shallower	= ($items[$lastitem]->level - ($start?$start:1));
				}
			}

			$cache->store($items, $key);
		}
		return $items;
	}

	private static function getAllItemsOrderedByMenuType() {
		$db = JFactory::getDbo();
		$query	= $db->getQuery(true);
		
		$query->select('menutype');
		$query->from('#__menu_types');
		$query->order('title, menutype');
		$db->setQuery($query);

		try {
			$menuTypes = $db->loadColumn();    
		} catch (JDatabaseException $e) {
			return array();
		}

		$app = JFactory::getApplication();
		$menu = $app->getMenu();

		$items = array();
		foreach ($menuTypes as $menutype) {
			$items = array_merge($items, $menu->getItems('menutype', $menutype));
		}

		return $items;
	}
}
